#include <Arduino.h>

#if defined(ESP32) || defined(ARDUINO_RASPBERRY_PI_PICO_W)
  #include <WiFi.h>

#elif defined(ESP8266)
  #include <ESP8266WiFi.h>

#elif defined(ARDUINO_UNOR4_WIFI)
    #include <WiFiS3.h>

#elif defined(ARDUINO_SAMD_MKRWIFI1010) || defined(ARDUINO_SAMD_NANO_33_IOT) || defined(ARDUINO_AVR_UNO_WIFI_REV2)
    #include <WiFiNINA.h>

#elif defined(ARDUINO_SAMD_MKR1000)
    #include <WiFi101.h>

#elif defined(ARDUINO_PORTENTA_H7_M7) || defined(ARDUINO_NICLA_VISION) || defined(ARDUINO_GIGA) || defined(ARDUINO_OPTA) 
    #include <WiFi.h>

#elif defined(ARDUINO_PORTENTA_C33)
    #include <WiFiC3.h>

#endif

#include <DHT.h>

int dht_sensor_pin = 14; // <<<< change this to the digital pin where your sensor is connected

// if using the included DHT library
DHT dht_sensor; 
// if using the Adafruit sensor library as a dependency un-comment line below and comment the line above
// DHT dht_sensor(dht_sensor_pin, DHT11);

#include <ChipChopManager.h> 
ChipChopManager ChipChop;

String server_uri = "...your allocated Endpoint Server URI..."; //found in the Dev Console > My Account
String uuid = "...your ChipChop UUID ..."; //found in the Dev Console > My Account
String auth_code = "... your Security Authentication Code ..."; //found in the Dev Console > My Account

String device_id = "... your Device ID ..."; // same unique id as in the Dev Console > Devices for this device

unsigned long loopCycle = 0;
float temperature = -1000.0;
float humidity = -1000.0;


void setup(){

    Serial.begin(115200);

    WiFi.begin("your SSID", "your wifi password");

    Serial.print("WiFi Connecting");
    while (WiFi.status() != WL_CONNECTED)
    {
        delay(500);
        Serial.print(".");
    }

    ChipChop.start(server_uri, uuid, device_id, auth_code);
    ChipChop.debug(true);
    
    // if using the included DHT library
    dht_sensor.begin(dht_sensor_pin, DHT11);
    // if using the Adafruit sensor library as a dependency un-comment line below and comment the line above
    // dht_sensor.begin();

}


void loop(){

    ChipChop.run();

    if((millis() - loopCycle) > 10000){

        temperature = dht_sensor.readTemperature();
        humidity = dht_sensor.readHumidity();

        if(isnan(temperature) || isnan(humidity)) {
            temperature = -1000.0;
            humidity = -1000.0;
        }
        ChipChop.updateStatus("temperature",temperature);
        ChipChop.updateStatus("humidity",humidity);


        loopCycle = millis();
    }

}

